package com.fidms.web.service;

import java.util.List;
import com.fidms.web.domain.Model3d;

/**
 * 3d模型Service接口
 * 
 * @author Allen
 * @date 2023-05-08
 */
public interface IModel3dService 
{
    /**
     * 查询3d模型
     * 
     * @param id 3d模型主键
     * @return 3d模型
     */
    public Model3d selectModel3dById(Long id);

    /**
     * 查询3d模型列表
     * 
     * @param model3d 3d模型
     * @return 3d模型集合
     */
    public List<Model3d> selectModel3dList(Model3d model3d);

    /**
     * 新增3d模型
     * 
     * @param model3d 3d模型
     * @return 结果
     */
    public int insertModel3d(Model3d model3d);

    /**
     * 修改3d模型
     * 
     * @param model3d 3d模型
     * @return 结果
     */
    public int updateModel3d(Model3d model3d);

    /**
     * 批量删除3d模型
     * 
     * @param ids 需要删除的3d模型主键集合
     * @return 结果
     */
    public int deleteModel3dByIds(Long[] ids);

    /**
     * 删除3d模型信息
     * 
     * @param id 3d模型主键
     * @return 结果
     */
    public int deleteModel3dById(Long id);

    List getOption();
}
